from distutils.core import setup

setup(
    name         =   'cff_utily',
    version      =   '1.0.0',
    py_modules   =   ['cff_utily'],
    author       =   'codingforfun',
    author_email =   'chang.yu.chn@gmail.com',
    url          =   'http://learning.llce.com.hk',
    description  =   'A simple printer of nester lists',
)